Class: TagApi::Tag

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_tag_api/models/tag.rb

Overview

Tag model.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Tag

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/pnap_tag_api/models/tag.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TagApi::Tag` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TagApi::Tag`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'values')
    if (value = attributes[:'values']).is_a?(Array)
      self.values = value
    end
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'is_billing_tag')
    self.is_billing_tag = attributes[:'is_billing_tag']
  else
    self.is_billing_tag = nil
  end

  if attributes.key?(:'resource_assignments')
    if (value = attributes[:'resource_assignments']).is_a?(Array)
      self.resource_assignments = value
    end
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  else
    self.created_by = 'USER'
  end
end

Instance Attribute Details

#created_byObject

The tag’s creator.



38
39
40
# File 'lib/pnap_tag_api/models/tag.rb', line 38

def created_by
  @created_by
end

#descriptionObject

The description of the tag.



29
30
31
# File 'lib/pnap_tag_api/models/tag.rb', line 29

def description
  @description
end

#idObject

The unique id of the tag.



20
21
22
# File 'lib/pnap_tag_api/models/tag.rb', line 20

def id
  @id
end

#is_billing_tagObject

Whether or not to show the tag as part of billing and invoices.



32
33
34
# File 'lib/pnap_tag_api/models/tag.rb', line 32

def is_billing_tag
  @is_billing_tag
end

#nameObject

The name of the tag.



23
24
25
# File 'lib/pnap_tag_api/models/tag.rb', line 23

def name
  @name
end

#resource_assignmentsObject

The tag’s assigned resources.



35
36
37
# File 'lib/pnap_tag_api/models/tag.rb', line 35

def resource_assignments
  @resource_assignments
end

#valuesObject

The optional values of the tag.



26
27
28
# File 'lib/pnap_tag_api/models/tag.rb', line 26

def values
  @values
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/pnap_tag_api/models/tag.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/pnap_tag_api/models/tag.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/pnap_tag_api/models/tag.rb', line 63

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'values' => :'values',
    :'description' => :'description',
    :'is_billing_tag' => :'isBillingTag',
    :'resource_assignments' => :'resourceAssignments',
    :'created_by' => :'createdBy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/pnap_tag_api/models/tag.rb', line 262

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
# File 'lib/pnap_tag_api/models/tag.rb', line 99

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
# File 'lib/pnap_tag_api/models/tag.rb', line 86

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'values' => :'Array<String>',
    :'description' => :'String',
    :'is_billing_tag' => :'Boolean',
    :'resource_assignments' => :'Array<ResourceAssignment>',
    :'created_by' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



235
236
237
238
239
240
241
242
243
244
245
# File 'lib/pnap_tag_api/models/tag.rb', line 235

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      values == o.values &&
      description == o.description &&
      is_billing_tag == o.is_billing_tag &&
      resource_assignments == o.resource_assignments &&
      created_by == o.created_by
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


249
250
251
# File 'lib/pnap_tag_api/models/tag.rb', line 249

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



255
256
257
# File 'lib/pnap_tag_api/models/tag.rb', line 255

def hash
  [id, name, values, description, is_billing_tag, resource_assignments, created_by].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/pnap_tag_api/models/tag.rb', line 163

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @is_billing_tag.nil?
    invalid_properties.push('invalid value for "is_billing_tag", is_billing_tag cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/pnap_tag_api/models/tag.rb', line 284

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
187
188
189
190
191
# File 'lib/pnap_tag_api/models/tag.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @is_billing_tag.nil?
  created_by_validator = EnumAttributeValidator.new('String', ["USER", "SYSTEM"])
  return false unless created_by_validator.valid?(@created_by)
  true
end